@@ -31,13 +31,13 @@ protected:
 	virtual int ResetOperation(int nErrorCode);
 
 	virtual int Connect(const CServer &server);
-	virtual int List(CServerPath path = CServerPath(), wxString subDir = _T(""), int flags = 0);
+	virtual int List(CServerPath path = CServerPath(), std::wstring const& subDir = std::wstring(), int flags = 0);
 	int ListParseResponse();
 	int ListSubcommandResult(int prevResult);
 	int ListSend();
 	int ListCheckTimezoneDetection(CDirectoryListing& listing);
 
-	int ChangeDir(CServerPath path = CServerPath(), wxString subDir = _T(""), bool link_discovery = false);
+	int ChangeDir(CServerPath path = CServerPath(), std::wstring subDir = std::wstring(), bool link_discovery = false);
 	int ChangeDirParseResponse();
 	int ChangeDirSubcommandResult(int prevResult);
 	int ChangeDirSend();
@@ -50,7 +50,7 @@ protected:
 	int FileTransferSend();
 	int FileTransferTestResumeCapability();
 
-	virtual int RawCommand(const wxString& command);
+	virtual int RawCommand(std::wstring const& command);
 	int RawCommandSend();
 	int RawCommandParseResponse();
 
@@ -59,7 +59,7 @@ protected:
 	int DeleteSend();
 	int DeleteParseResponse();
 
-	virtual int RemoveDir(const CServerPath& path, const wxString& subDir);
+	virtual int RemoveDir(CServerPath const& path, std::wstring const& subDir);
 	int RemoveDirSubcommandResult(int prevResult);
 	int RemoveDirSend();
 	int RemoveDirParseResponse();
@@ -78,23 +78,23 @@ protected:
 	virtual int ChmodSubcommandResult(int prevResult);
 	virtual int ChmodSend();
 
-	virtual int Transfer(const wxString& cmd, CFtpTransferOpData* oldData);
+	virtual int Transfer(std::wstring const& cmd, CFtpTransferOpData* oldData);
 	virtual int TransferParseResponse();
 	virtual int TransferSend();
 
 	virtual void OnConnect();
 	virtual void OnReceive();
 
-	bool SendCommand(wxString const& str, bool maskArgs = false, bool measureRTT = true);
+	bool SendCommand(std::wstring const& str, bool maskArgs = false, bool measureRTT = true);
 
 	// Parse the latest reply line from the server
-	void ParseLine(wxString line);
+	void ParseLine(std::wstring line);
 
 	// Parse the actual response and delegate it to the handlers.
 	// It's the last line in a multi-line response.
 	void ParseResponse();
 
-	void ParseFeat(wxString line);
+	void ParseFeat(std::wstring const& line);
 
 	virtual int SendNextCommand();
 	virtual int ParseSubcommandResult(int prevResult);
@@ -105,7 +105,7 @@ protected:
 	int LogonParseResponse();
 	int LogonSend();
 
-	wxString GetPassiveCommand(CRawTransferOpData& data);
+	std::wstring GetPassiveCommand(CRawTransferOpData& data);
 	bool ParsePasvResponse(CRawTransferOpData* pData);
 	bool ParseEpsvResponse(CRawTransferOpData* pData);
 
@@ -123,9 +123,9 @@ protected:
 
 	bool GetLoginSequence(const CServer& server);
 
-	wxString m_Response;
-	wxString m_MultilineResponseCode;
-	std::vector<wxString> m_MultilineResponseLines;
+	std::wstring m_Response;
+	std::wstring m_MultilineResponseCode;
+	std::vector<std::wstring> m_MultilineResponseLines;
 
 	CTransferSocket *m_pTransferSocket;
 
@@ -187,20 +187,4 @@ public:
 	bool fileDidExist{true};
 };
 
-class CRawTransferOpData final : public COpData
-{
-public:
-	CRawTransferOpData();
-	wxString cmd;
-
-	CFtpTransferOpData* pOldData;
-
-	bool bPasv;
-	bool bTriedPasv;
-	bool bTriedActive;
-
-	wxString host;
-	int port;
-};
-
 #endif
