@@ -10,7 +10,7 @@
 #include <random>
 #include <cstdint>
 
-wxString GetDependencyVersion(lib_dependency d)
+std::wstring GetDependencyVersion(lib_dependency d)
 {
 	switch (d) {
 	case lib_dependency::wxwidgets:
@@ -18,29 +18,30 @@ wxString GetDependencyVersion(lib_dependency d)
 	case lib_dependency::gnutls:
 		{
 			const char* v = gnutls_check_version(0);
-			if (!v || !*v)
-				return _T("unknown");
+			if (!v || !*v) {
+				return L"unknown";
+			}
 
-			return wxString(v, wxConvLibc);
+			return fz::to_wstring(v);
 		}
 	case lib_dependency::sqlite:
-		return wxString::FromUTF8(sqlite3_libversion());
+		return fz::to_wstring_from_utf8(sqlite3_libversion());
 	default:
-		return wxString();
+		return std::wstring();
 	}
 }
 
-wxString GetDependencyName(lib_dependency d)
+std::wstring GetDependencyName(lib_dependency d)
 {
 	switch (d) {
 	case lib_dependency::wxwidgets:
-		return _T("wxWidgets");
+		return L"wxWidgets";
 	case lib_dependency::gnutls:
-		return _T("GnuTLS");
+		return L"GnuTLS";
 	case lib_dependency::sqlite:
-		return _T("SQLite");
+		return L"SQLite";
 	default:
-		return wxString();
+		return std::wstring();
 	}
 }
 
@@ -116,3 +117,63 @@ std::wstring url_encode(std::wstring const& s, bool keep_slashes)
 
 	return ret;
 }
+
+#if FZ_WINDOWS
+DWORD GetSystemErrorCode()
+{
+	return GetLastError();
+}
+
+std::wstring GetSystemErrorDescription(DWORD err)
+{
+	wchar_t* buf{};
+	if (!FormatMessage(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM, 0, err, MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), reinterpret_cast<wchar_t*>(&buf), 0, 0) || !buf) {
+		return fz::sprintf(_("Unknown error %u"), err);
+	}
+	std::wstring ret = buf;
+	LocalFree(buf);
+
+	return ret;
+}
+#else
+int GetSystemErrorCode()
+{
+	return errno;
+}
+
+namespace {
+inline std::string ProcessStrerrorResult(int ret, char* buf, int err)
+{
+	// For XSI strerror_r
+	std::string s;
+	if (!ret) {
+		buf[999] = 0;
+		s = buf;
+	}
+	else {
+		s = fz::to_string(fz::sprintf(_("Unknown error %d"), err));
+	}
+	return s;
+}
+
+inline std::string ProcessStrerrorResult(char* ret, char*, int err)
+{
+	// For GNU strerror_r
+	std::string s;
+	if (ret) {
+		s = ret;
+	}
+	else {
+		s = fz::to_string(fz::sprintf(_("Unknown error %d"), err));
+	}
+	return s;
+}
+}
+
+std::string GetSystemErrorDescription(int err)
+{
+	char buf[1000];
+	auto ret = strerror_r(err, buf, 1000);
+	return ProcessStrerrorResult(ret, buf, err);
+}
+#endif
