@@ -3,26 +3,26 @@
 struct t_protocolInfo
 {
 	const ServerProtocol protocol;
-	const wxString prefix;
+	std::wstring const prefix;
 	bool alwaysShowPrefix;
 	unsigned int defaultPort;
 	const bool translateable;
-	const wxChar* const name;
+	const wchar_t* const name;
 	bool supportsPostlogin;
 };
 
 static const t_protocolInfo protocolInfos[] = {
-	{ FTP,          _T("ftp"),    false, 21,  true,  TRANSLATE_T("FTP - File Transfer Protocol with optional encryption"),                 true  },
+	{ FTP,          _T("ftp"),    false, 21,  true,  TRANSLATE_T("FTP - File Transfer Protocol with optional encryption"), true  },
 	{ SFTP,         _T("sftp"),   true,  22,  false, _T("SFTP - SSH File Transfer Protocol"),                              false },
-	{ HTTP,         _T("http"),   true,  80,  false, _T("HTTP - Hypertext Transfer Protocol"),                             false  },
-	{ HTTPS,        _T("https"),  true, 443,  true,  TRANSLATE_T("HTTPS - HTTP over TLS"),                                 false  },
-	{ FTPS,         _T("ftps"),   true, 990,  true,  TRANSLATE_T("FTPS - FTP over implicit TLS"),                      true  },
-	{ FTPES,        _T("ftpes"),  true,  21,  true,  TRANSLATE_T("FTPES - FTP over explicit TLS"),                     true  },
-	{ INSECURE_FTP, _T("ftp"),    false, 21,  true,  TRANSLATE_T("FTP - Insecure File Transfer Protocol"), true  },
+	{ HTTP,         _T("http"),   true,  80,  false, _T("HTTP - Hypertext Transfer Protocol"),                             false },
+	{ HTTPS,        _T("https"),  true, 443,  true,  TRANSLATE_T("HTTPS - HTTP over TLS"),                                 false },
+	{ FTPS,         _T("ftps"),   true, 990,  true,  TRANSLATE_T("FTPS - FTP over implicit TLS"),                          true  },
+	{ FTPES,        _T("ftpes"),  true,  21,  true,  TRANSLATE_T("FTPES - FTP over explicit TLS"),                         true  },
+	{ INSECURE_FTP, _T("ftp"),    false, 21,  true,  TRANSLATE_T("FTP - Insecure File Transfer Protocol"),                 true  },
 	{ UNKNOWN,      _T(""),       false, 21,  false, _T(""), false }
 };
 
-static const wxString typeNames[SERVERTYPE_MAX] = {
+static const std::wstring typeNames[SERVERTYPE_MAX] = {
 	TRANSLATE_T("Default (Autodetect)"),
 	_T("Unix"),
 	_T("VMS"),
@@ -39,10 +39,10 @@ static const wxString typeNames[SERVERTYPE_MAX] = {
 static const t_protocolInfo& GetProtocolInfo(ServerProtocol protocol)
 {
 	unsigned int i = 0;
-	for ( ; protocolInfos[i].protocol != UNKNOWN; ++i)
-	{
-		if (protocolInfos[i].protocol == protocol)
+	for ( ; protocolInfos[i].protocol != UNKNOWN; ++i) {
+		if (protocolInfos[i].protocol == protocol) {
 			break;
+		}
 	}
 	return protocolInfos[i];
 }
@@ -52,160 +52,148 @@ CServer::CServer()
 	Initialize();
 }
 
-bool CServer::ParseUrl(wxString host, wxString port, wxString user, wxString pass, wxString &error, CServerPath &path)
+bool CServer::ParseUrl(std::wstring const& host, std::wstring const& port, std::wstring const& user, std::wstring const& pass, std::wstring &error, CServerPath &path)
 {
-	unsigned long nPort = 0;
-	if (!port.empty())
-	{
-		port.Trim(false);
-		port.Trim(true);
-		if (port.size() > 5 || !port.ToULong(&nPort) || !nPort || nPort > 65535)
-		{
-			error = _("Invalid port given. The port has to be a value from 1 to 65535.");
-			error += _T("\n");
-			error += _("You can leave the port field empty to use the default port.");
+	unsigned int nPort = 0;
+	if (!port.empty()) {
+		nPort = fz::to_integral<unsigned int>(fz::trimmed(port));
+		if (port.size() > 5 || !nPort || nPort > 65535) {
+			error = _("Invalid port given. The port has to be a value from 1 to 65535.").ToStdWstring();
+			error += L"\n";
+			error += _("You can leave the port field empty to use the default port.").ToStdWstring();
 			return false;
 		}
 	}
 	return ParseUrl(host, nPort, user, pass, error, path);
 }
 
-bool CServer::ParseUrl(wxString host, unsigned int port, wxString user, wxString pass, wxString &error, CServerPath &path)
+bool CServer::ParseUrl(std::wstring host, unsigned int port, std::wstring user, std::wstring pass, std::wstring &error, CServerPath &path)
 {
 	m_type = DEFAULT;
 
 	if (host.empty()) {
-		error = _("No host given, please enter a host.");
+		error = _("No host given, please enter a host.").ToStdWstring();
 		return false;
 	}
 
-	int pos = host.Find(_T("://"));
-	if (pos != -1) {
-		wxString protocol = host.Left(pos).Lower();
-		host = host.Mid(pos + 3);
-		if (protocol.Left(3) == _T("fz_"))
-			protocol = protocol.Mid(3);
-		m_protocol = GetProtocolFromPrefix(protocol.Lower());
-		if (m_protocol == UNKNOWN)
-		{
-			// TODO: http:// once WebDAV is officially supported
-			error = _("Invalid protocol specified. Valid protocols are:\nftp:// for normal FTP with optional encryption,\nsftp:// for SSH file transfer protocol,\nftps:// for FTP over TLS (implicit) and\nftpes:// for FTP over TLS (explicit).");
+	size_t pos = host.find(L"://");
+	if (pos != std::wstring::npos) {
+		std::wstring protocol = fz::str_tolower_ascii(host.substr(0, pos));
+		host = host.substr(pos + 3);
+		if (protocol.substr(0, 3) == L"fz_") {
+			protocol = protocol.substr(3);
+		}
+		m_protocol = GetProtocolFromPrefix(protocol);
+		if (m_protocol == UNKNOWN) {
+			error = _("Invalid protocol specified. Valid protocols are:\nftp:// for normal FTP with optional encryption,\nsftp:// for SSH file transfer protocol,\nftps:// for FTP over TLS (implicit) and\nftpes:// for FTP over TLS (explicit).").ToStdWstring();
 			return false;
 		}
 	}
 
-	pos = host.Find('@');
-	if (pos != -1) {
+	pos = host.find('@');
+	if (pos != std::wstring::npos) {
 		// Check if it's something like
 		//   user@name:password@host:port/path
 		// => If there are multiple at signs, username/port ends at last at before
 		// the first slash. (Since host and port never contain any at sign)
 
-		int slash = host.Mid(pos + 1).Find('/');
-		if (slash != -1)
-			slash += pos + 1;
+		size_t slash = host.find('/', pos + 1);
 
-		int next_at = host.Mid(pos + 1).Find('@');
-		while (next_at != -1) {
-			next_at += pos + 1;
-			if (slash != -1 && next_at > slash)
+		size_t next_at = host.find('@', pos + 1);
+		while (next_at != std::wstring::npos) {
+			if (slash != std::wstring::npos  && next_at > slash) {
 				break;
+			}
 
 			pos = next_at;
-			next_at = host.Mid(pos + 1).Find('@');
+			next_at = host.find('@', next_at + 1);
 		}
 
-		user = host.Left(pos);
-		host = host.Mid(pos + 1);
+		user = host.substr(0, pos);
+		host = host.substr(pos + 1);
 
 		// Extract password (if any) from username
-		pos = user.Find(':');
-		if (pos != -1) {
-			pass = user.Mid(pos + 1);
-			user = user.Left(pos);
+		pos = user.find(':');
+		if (pos != std::wstring::npos) {
+			pass = user.substr(pos + 1);
+			user = user.substr(0, pos);
 		}
 
 		// Remove leading and trailing whitespace
-		user.Trim(true);
-		user.Trim(false);
+		fz::trim(user);
 
 		if (user.empty()) {
-			error = _("Invalid username given.");
+			error = _("Invalid username given.").ToStdWstring();
 			return false;
 		}
 	}
 	else {
 		// Remove leading and trailing whitespace
-		user.Trim(true);
-		user.Trim(false);
+		fz::trim(user);
 
 		if (user.empty() && m_logonType != ASK && m_logonType != INTERACTIVE) {
-			user = _T("anonymous");
-			pass = _T("anonymous@example.com");
+			user = L"anonymous";
+			pass = L"anonymous@example.com";
 		}
 	}
 
-	pos = host.Find('/');
-	if (pos != -1) {
-		path = CServerPath(host.Mid(pos));
-		host = host.Left(pos);
+	pos = host.find('/');
+	if (pos != std::wstring::npos) {
+		path = CServerPath(host.substr(pos));
+		host = host.substr(0, pos);
 	}
 
 	if (!host.empty() && host[0] == '[') {
 		// Probably IPv6 address
-		pos = host.Find(']');
-		if (pos == -1) {
-			error = _("Host starts with '[' but no closing bracket found.");
+		pos = host.find(']');
+		if (pos == std::wstring::npos) {
+			error = _("Host starts with '[' but no closing bracket found.").ToStdWstring();
 			return false;
 		}
-		if (pos + 1 < static_cast<int>(host.Len()) ) {
+		if (pos < host.size() - 1 ) {
 			if (host[pos + 1] != ':') {
-				error = _("Invalid host, after closing bracket only colon and port may follow.");
+				error = _("Invalid host, after closing bracket only colon and port may follow.").ToStdWstring();
 				return false;
 			}
 			++pos;
 		}
 		else
-			pos = -1;
-	}
-	else
-		pos = host.Find(':');
-	if (pos != -1) {
-		if (!pos) {
-			error = _("No host given, please enter a host.");
-			return false;
-		}
-
-		long tmp;
-		if (!host.Mid(pos + 1).ToLong(&tmp) || tmp < 1 || tmp > 65535) {
-			error = _("Invalid port given. The port has to be a value from 1 to 65535.");
-			return false;
-		}
-		port = tmp;
-		host = host.Left(pos);
+			pos = std::wstring::npos;
 	}
 	else {
-		if (!port)
-			port = GetDefaultPort(m_protocol);
-		else if (port > 65535) {
-			error = _("Invalid port given. The port has to be a value from 1 to 65535.");
+		pos = host.find(':');
+	}
+	if (pos != std::wstring::npos) {
+		if (!pos) {
+			error = _("No host given, please enter a host.").ToStdWstring();
 			return false;
 		}
+
+		port = fz::to_integral<unsigned int>(host.substr(pos + 1));
+		host = host.substr(0, pos);
+	}
+	else {
+		if (!port) {
+			port = GetDefaultPort(m_protocol);
+		}
 	}
 
-	host.Trim(true);
-	host.Trim(false);
+	if (port < 1 || port > 65535) {
+		error = _("Invalid port given. The port has to be a value from 1 to 65535.").ToStdWstring();
+		return false;
+	}
+	
+	fz::trim(host);
 
 	if (host.empty()) {
-		error = _("No host given, please enter a host.");
+		error = _("No host given, please enter a host.").ToStdWstring();
 		return false;
 	}
 
 	m_host = host;
 
 	if (m_host[0] == '[') {
-		m_host.RemoveLast();
-		m_host = m_host.Mid(1);
+		m_host = m_host.substr(1, m_host.size() - 2);
 	}
 
 	m_port = port;
@@ -213,19 +201,25 @@ bool CServer::ParseUrl(wxString host, unsigned int port, wxString user, wxString
 	m_pass = pass;
 	m_account.clear();
 	if (m_logonType != ASK && m_logonType != INTERACTIVE) {
-		if (m_user.empty())
+		if (m_user.empty()) {
 			m_logonType = ANONYMOUS;
-		else if (m_user == _T("anonymous"))
-			if (m_pass.empty() || m_pass == _T("anonymous@example.com"))
+		}
+		else if (m_user == "anonymous") {
+			if (m_pass.empty() || m_pass == L"anonymous@example.com") {
 				m_logonType = ANONYMOUS;
-			else
+			}
+			else {
 				m_logonType = NORMAL;
-		else
+			}
+		}
+		else {
 			m_logonType = NORMAL;
+		}
 	}
 
-	if (m_protocol == UNKNOWN)
+	if (m_protocol == UNKNOWN) {
 		m_protocol = GetProtocolFromPort(port);
+	}
 
 	return true;
 }
@@ -240,7 +234,7 @@ ServerType CServer::GetType() const
 	return m_type;
 }
 
-wxString CServer::GetHost() const
+std::wstring CServer::GetHost() const
 {
 	return m_host;
 }
@@ -250,26 +244,29 @@ unsigned int CServer::GetPort() const
 	return m_port;
 }
 
-wxString CServer::GetUser() const
+std::wstring CServer::GetUser() const
 {
-	if (m_logonType == ANONYMOUS)
-		return _T("anonymous");
+	if (m_logonType == ANONYMOUS) {
+		return L"anonymous";
+	}
 
 	return m_user;
 }
 
-wxString CServer::GetPass() const
+std::wstring CServer::GetPass() const
 {
-	if (m_logonType == ANONYMOUS)
-		return _T("anon@localhost");
+	if (m_logonType == ANONYMOUS) {
+		return L"anon@localhost";
+	}
 
 	return m_pass;
 }
 
-wxString CServer::GetAccount() const
+std::wstring CServer::GetAccount() const
 {
-	if (m_logonType != ACCOUNT)
-		return wxString();
+	if (m_logonType != ACCOUNT) {
+		return std::wstring();
+	}
 
 	return m_account;
 }
@@ -374,11 +371,13 @@ bool CServer::operator<(const CServer &op) const
 	else if (m_type > op.m_type)
 		return false;
 
-	int cmp = m_host.Cmp(op.m_host);
-	if (cmp < 0)
+	int cmp = m_host.compare(op.m_host);
+	if (cmp < 0) {
 		return true;
-	else if (cmp > 0)
+	}
+	else if (cmp > 0) {
 		return false;
+	}
 
 	if (m_port < op.m_port)
 		return true;
@@ -392,7 +391,7 @@ bool CServer::operator<(const CServer &op) const
 
 	if (m_logonType != ANONYMOUS)
 	{
-		cmp = m_user.Cmp(op.m_user);
+		cmp = m_user.compare(op.m_user);
 		if (cmp < 0)
 			return true;
 		else if (cmp > 0)
@@ -400,7 +399,7 @@ bool CServer::operator<(const CServer &op) const
 
 		if (m_logonType == NORMAL)
 		{
-			cmp = m_pass.Cmp(op.m_pass);
+			cmp = m_pass.compare(op.m_pass);
 			if (cmp < 0)
 				return true;
 			else if (cmp > 0)
@@ -408,13 +407,13 @@ bool CServer::operator<(const CServer &op) const
 		}
 		else if (m_logonType == ACCOUNT)
 		{
-			cmp = m_pass.Cmp(op.m_pass);
+			cmp = m_pass.compare(op.m_pass);
 			if (cmp < 0)
 				return true;
 			else if (cmp > 0)
 				return false;
 
-			cmp = m_account.Cmp(op.m_account);
+			cmp = m_account.compare(op.m_account);
 			if (cmp < 0)
 				return true;
 			else if (cmp > 0)
@@ -500,7 +499,7 @@ bool CServer::EqualsNoPass(const CServer &op) const
 	return true;
 }
 
-CServer::CServer(ServerProtocol protocol, ServerType type, wxString host, unsigned int port, wxString user, wxString pass, wxString account)
+CServer::CServer(ServerProtocol protocol, ServerType type, std::wstring const& host, unsigned int port, std::wstring const& user, std::wstring const& pass, std::wstring const& account)
 {
 	Initialize();
 	m_protocol = protocol;
@@ -513,7 +512,7 @@ CServer::CServer(ServerProtocol protocol, ServerType type, wxString host, unsign
 	m_account = account;
 }
 
-CServer::CServer(ServerProtocol protocol, ServerType type, wxString host, unsigned int port)
+CServer::CServer(ServerProtocol protocol, ServerType type, std::wstring const& host, unsigned int port)
 {
 	Initialize();
 	m_protocol = protocol;
@@ -534,69 +533,78 @@ LogonType CServer::GetLogonType() const
 
 void CServer::SetLogonType(LogonType logonType)
 {
-	wxASSERT(logonType != LOGONTYPE_MAX);
+	assert(logonType != LOGONTYPE_MAX);
 	m_logonType = logonType;
 }
 
 void CServer::SetProtocol(ServerProtocol serverProtocol)
 {
-	wxASSERT(serverProtocol != UNKNOWN);
+	assert(serverProtocol != UNKNOWN);
 
-	if (!GetProtocolInfo(serverProtocol).supportsPostlogin)
+	if (!GetProtocolInfo(serverProtocol).supportsPostlogin) {
 		m_postLoginCommands.clear();
+	}
 
 	m_protocol = serverProtocol;
 }
 
-bool CServer::SetHost(wxString host, unsigned int port)
+bool CServer::SetHost(std::wstring const& host, unsigned int port)
 {
-	if (host.empty())
+	if (host.empty()) {
 		return false;
+	}
 
-	if (port < 1 || port > 65535)
+	if (port < 1 || port > 65535) {
 		return false;
+	}
 
 	m_host = host;
 	m_port = port;
 
-	if (m_protocol == UNKNOWN)
+	if (m_protocol == UNKNOWN) {
 		m_protocol = GetProtocolFromPort(m_port);
+	}
 
 	return true;
 }
 
-bool CServer::SetUser(const wxString& user, const wxString& pass)
+bool CServer::SetUser(std::wstring const& user, std::wstring const& pass)
 {
-	if (m_logonType == ANONYMOUS)
+	if (m_logonType == ANONYMOUS) {
 		return true;
+	}
 
 	if (user.empty()) {
-		if (m_logonType != ASK && m_logonType != INTERACTIVE)
+		if (m_logonType != ASK && m_logonType != INTERACTIVE) {
 			return false;
+		}
 		m_pass.clear();
 	}
-	else
+	else {
 		m_pass = pass;
+	}
 
 	m_user = user;
 
 	return true;
 }
 
-bool CServer::SetAccount(const wxString& account)
+bool CServer::SetAccount(std::wstring const& account)
 {
-	if (m_logonType != ACCOUNT)
+	if (m_logonType != ACCOUNT) {
 		return false;
+	}
 
 	m_account = account;
 
 	return true;
 }
 
-bool CServer::SetKeyFile(const wxString& keyFile)
+bool CServer::SetKeyFile(std::wstring const& keyFile)
 {
-	if (m_logonType != KEY)
+	if (m_logonType != KEY) {
 		return false;
+	}
 
 	m_keyFile = keyFile;
 
@@ -605,8 +613,9 @@ bool CServer::SetKeyFile(const wxString& keyFile)
 
 bool CServer::SetTimezoneOffset(int minutes)
 {
-	if (minutes > (60 * 24) || minutes < (-60 * 24))
+	if (minutes > (60 * 24) || minutes < (-60 * 24)) {
 		return false;
+	}
 
 	m_timezoneOffset = minutes;
 
@@ -638,20 +647,22 @@ int CServer::MaximumMultipleConnections() const
 	return m_maximumMultipleConnections;
 }
 
-wxString CServer::Format(ServerFormat formatType) const
+std::wstring CServer::Format(ServerFormat formatType) const
 {
-	t_protocolInfo const& info = GetProtocolInfo(m_protocol);
-	wxString server = m_host;
+	std::wstring server = m_host;
 
-	if (server.Find(':') != -1)
+	t_protocolInfo const& info = GetProtocolInfo(m_protocol);
+
+	if (server.find(':') != std::wstring::npos) {
 		server = _T("[") + server + _T("]");
+	}
 
 	if (formatType == ServerFormat::host_only) {
 		return server;
 	}
 	
 	if (m_port != GetDefaultPort(m_protocol)) {
-		server += wxString::Format(_T(":%d"), m_port);
+		server += fz::sprintf(L":%d", m_port);
 	}
 
 	if (formatType == ServerFormat::with_optional_port) {
@@ -659,7 +670,7 @@ wxString CServer::Format(ServerFormat formatType) const
 	}
 		
 	if (m_logonType != ANONYMOUS) {
-		auto user = GetUser().ToStdWstring();
+		auto user = GetUser();
 		// For now, only escape if formatting for URL.
 		// Open question: Do we need some form of escapement for presentation within the GUI,
 		// that deals e.g. with whitespace but does not touch Unicode characters?
@@ -668,7 +679,7 @@ wxString CServer::Format(ServerFormat formatType) const
 		}
 		if (!user.empty()) {
 			if (formatType == ServerFormat::url_with_password) {
-				auto pass = GetPass().ToStdWstring();
+				auto pass = GetPass();
 				if (!pass.empty()) {
 					if (formatType == ServerFormat::url || formatType == ServerFormat::url_with_password) {
 						pass = url_encode(pass);
@@ -713,10 +724,11 @@ void CServer::Initialize()
 	m_bypassProxy = false;
 }
 
-bool CServer::SetEncodingType(CharsetEncoding type, const wxString& encoding)
+bool CServer::SetEncodingType(CharsetEncoding type, std::wstring const& encoding)
 {
-	if (type == ENCODING_CUSTOM && encoding.empty())
+	if (type == ENCODING_CUSTOM && encoding.empty()) {
 		return false;
+	}
 
 	m_encodingType = type;
 	m_customEncoding = encoding;
@@ -724,10 +736,11 @@ bool CServer::SetEncodingType(CharsetEncoding type, const wxString& encoding)
 	return true;
 }
 
-bool CServer::SetCustomEncoding(const wxString& encoding)
+bool CServer::SetCustomEncoding(std::wstring const& encoding)
 {
-	if (encoding.empty())
+	if (encoding.empty()) {
 		return false;
+	}
 
 	m_encodingType = ENCODING_CUSTOM;
 	m_customEncoding = encoding;
@@ -740,7 +753,7 @@ CharsetEncoding CServer::GetEncodingType() const
 	return m_encodingType;
 }
 
-wxString CServer::GetCustomEncoding() const
+std::wstring CServer::GetCustomEncoding() const
 {
 	return m_customEncoding;
 }
@@ -767,37 +780,39 @@ ServerProtocol CServer::GetProtocolFromPort(unsigned int port, bool defaultOnly
 	return FTP;
 }
 
-wxString CServer::GetProtocolName(ServerProtocol protocol)
+std::wstring CServer::GetProtocolName(ServerProtocol protocol)
 {
-	const t_protocolInfo *protocolInfo = protocolInfos;
-	while (protocolInfo->protocol != UNKNOWN)
-	{
-		if (protocolInfo->protocol != protocol)
-		{
+	t_protocolInfo const* protocolInfo = protocolInfos;
+	while (protocolInfo->protocol != UNKNOWN) {
+		if (protocolInfo->protocol != protocol) {
 			++protocolInfo;
 			continue;
 		}
 
-		if (protocolInfo->translateable)
-			return wxGetTranslation(protocolInfo->name);
-		else
+		if (protocolInfo->translateable) {
+			return wxGetTranslation(protocolInfo->name).ToStdWstring();
+		}
+		else {
 			return protocolInfo->name;
+		}
 	}
 
-	return wxString();
+	return std::wstring();
 }
 
-ServerProtocol CServer::GetProtocolFromName(const wxString& name)
+ServerProtocol CServer::GetProtocolFromName(std::wstring const& name)
 {
 	const t_protocolInfo *protocolInfo = protocolInfos;
 	while (protocolInfo->protocol != UNKNOWN) {
 		if (protocolInfo->translateable) {
-			if (wxGetTranslation(protocolInfo->name) == name)
+			if (wxGetTranslation(protocolInfo->name) == name) {
 				return protocolInfo->protocol;
+			}
 		}
 		else {
-			if (protocolInfo->name == name)
+			if (protocolInfo->name == name) {
 				return protocolInfo->protocol;
+			}
 		}
 		++protocolInfo;
 	}
@@ -805,7 +820,7 @@ ServerProtocol CServer::GetProtocolFromName(const wxString& name)
 	return UNKNOWN;
 }
 
-bool CServer::SetPostLoginCommands(const std::vector<wxString>& postLoginCommands)
+bool CServer::SetPostLoginCommands(const std::vector<std::wstring>& postLoginCommands)
 {
 	if (!SupportsPostLoginCommands(m_protocol)) {
 		m_postLoginCommands.clear();
@@ -821,17 +836,19 @@ bool CServer::SupportsPostLoginCommands(ServerProtocol const protocol)
 	return protocol == FTP || protocol == FTPS || protocol == FTPES || protocol == INSECURE_FTP;
 }
 
-ServerProtocol CServer::GetProtocolFromPrefix(const wxString& prefix)
+ServerProtocol CServer::GetProtocolFromPrefix(std::wstring const& prefix)
 {
+	std::wstring lower = fz::str_tolower_ascii(prefix);
 	for (unsigned int i = 0; protocolInfos[i].protocol != UNKNOWN; ++i) {
-		if (!protocolInfos[i].prefix.CmpNoCase(prefix))
+		if (protocolInfos[i].prefix == lower) {
 			return protocolInfos[i].protocol;
+		}
 	}
 
 	return UNKNOWN;
 }
 
-wxString CServer::GetPrefixFromProtocol(const ServerProtocol protocol)
+std::wstring CServer::GetPrefixFromProtocol(ServerProtocol const protocol)
 {
 	const t_protocolInfo& info = GetProtocolInfo(protocol);
 
@@ -840,40 +857,42 @@ wxString CServer::GetPrefixFromProtocol(const ServerProtocol protocol)
 
 void CServer::SetBypassProxy(bool val)
 {
-  m_bypassProxy = val;
+	m_bypassProxy = val;
 }
 
 bool CServer::GetBypassProxy() const
 {
-  return m_bypassProxy;
+	return m_bypassProxy;
 }
 
 bool CServer::ProtocolHasDataTypeConcept(const ServerProtocol protocol)
 {
-	if (protocol == FTP || protocol == FTPS || protocol == FTPES || protocol == INSECURE_FTP)
+	if (protocol == FTP || protocol == FTPS || protocol == FTPES || protocol == INSECURE_FTP) {
 		return true;
+	}
 
 	return false;
 }
 
-wxString CServer::GetNameFromServerType(ServerType type)
+std::wstring CServer::GetNameFromServerType(ServerType type)
 {
-	wxASSERT(type != SERVERTYPE_MAX);
-	return wxGetTranslation(typeNames[type]);
+	assert(type != SERVERTYPE_MAX);
+	return wxGetTranslation(typeNames[type]).ToStdWstring();
 }
 
-ServerType CServer::GetServerTypeFromName(const wxString& name)
+ServerType CServer::GetServerTypeFromName(std::wstring const& name)
 {
 	for (int i = 0; i < SERVERTYPE_MAX; ++i) {
 		ServerType type = static_cast<ServerType>(i);
-		if (name == CServer::GetNameFromServerType(type))
+		if (name == CServer::GetNameFromServerType(type)) {
 			return type;
+		}
 	}
 
 	return DEFAULT;
 }
 
-LogonType CServer::GetLogonTypeFromName(const wxString& name)
+LogonType CServer::GetLogonTypeFromName(std::wstring const& name)
 {
 	if (name == _("Normal"))
 		return NORMAL;
@@ -889,23 +908,23 @@ LogonType CServer::GetLogonTypeFromName(const wxString& name)
 		return ANONYMOUS;
 }
 
-wxString CServer::GetNameFromLogonType(LogonType type)
+std::wstring CServer::GetNameFromLogonType(LogonType type)
 {
-	wxASSERT(type != LOGONTYPE_MAX);
+	assert(type != LOGONTYPE_MAX);
 
 	switch (type)
 	{
 	case NORMAL:
-		return _("Normal");
+		return _("Normal").ToStdWstring();
 	case ASK:
-		return _("Ask for password");
+		return _("Ask for password").ToStdWstring();
 	case KEY:
-		return _("Key file");
+		return _("Key file").ToStdWstring();
 	case INTERACTIVE:
-		return _("Interactive");
+		return _("Interactive").ToStdWstring();
 	case ACCOUNT:
-		return _("Account");
+		return _("Account").ToStdWstring();
 	default:
-		return _("Anonymous");
+		return _("Anonymous").ToStdWstring();
 	}
 }
