@@ -7,6 +7,8 @@
 
 #include <gnutls/x509.h>
 
+#include <algorithm>
+
 #if FZ_USE_GNUTLS_SYSTEM_CIPHERS
 char const ciphers[] = "@SYSTEM";
 #else
@@ -19,10 +21,11 @@ char const ciphers[] = "SECURE256:+SECURE128:-ARCFOUR-128:-3DES-CBC:-MD5:+SIGN-A
 CControlSocket* pLoggingControlSocket;
 void log_func(int level, const char* msg)
 {
-	if (!msg || !pLoggingControlSocket)
+	if (!msg || !pLoggingControlSocket) {
 		return;
-	wxString s(msg, wxConvLocal);
-	s.Trim();
+	}
+	std::wstring s = fz::to_wstring(msg);
+	fz::trim(s);
 	pLoggingControlSocket->LogMessage(MessageType::Debug_Debug, _T("tls: %d %s"), level, s);
 }
 #endif
@@ -278,7 +281,7 @@ void CTlsSocket::UninitSession()
 }
 
 
-void CTlsSocket::LogError(int code, const wxString& function, MessageType logLevel)
+void CTlsSocket::LogError(int code, std::wstring const& function, MessageType logLevel)
 {
 	if (code == GNUTLS_E_WARNING_ALERT_RECEIVED || code == GNUTLS_E_FATAL_ALERT_RECEIVED) {
 		PrintAlert(logLevel);
@@ -302,17 +305,20 @@ void CTlsSocket::LogError(int code, const wxString& function, MessageType logLev
 	else {
 		const char* error = gnutls_strerror(code);
 		if (error) {
-			wxString str(error, wxConvLocal);
-			if (function.empty())
-				m_pOwner->LogMessage(logLevel, _("GnuTLS error %d: %s"), code, str);
-			else
-				m_pOwner->LogMessage(logLevel, _("GnuTLS error %d in %s: %s"), code, function, str);
+			if (function.empty()) {
+				m_pOwner->LogMessage(logLevel, _("GnuTLS error %d: %s"), code, error);
+			}
+			else {
+				m_pOwner->LogMessage(logLevel, _("GnuTLS error %d in %s: %s"), code, function, error);
+			}
 		}
 		else {
-			if (function.empty())
+			if (function.empty()) {
 				m_pOwner->LogMessage(logLevel, _("GnuTLS error %d"), code);
-			else
+			}
+			else {
 				m_pOwner->LogMessage(logLevel, _("GnuTLS error %d in %s"), code, function);
+			}
 		}
 	}
 }
@@ -322,11 +328,11 @@ void CTlsSocket::PrintAlert(MessageType logLevel)
 	gnutls_alert_description_t last_alert = gnutls_alert_get(m_session);
 	const char* alert = gnutls_alert_get_name(last_alert);
 	if (alert) {
-		wxString str(alert, wxConvLocal);
-		m_pOwner->LogMessage(logLevel, _("Received TLS alert from the server: %s (%d)"), str, last_alert);
+		m_pOwner->LogMessage(logLevel, _("Received TLS alert from the server: %s (%d)"), alert, last_alert);
 	}
-	else
+	else {
 		m_pOwner->LogMessage(logLevel, _("Received unknown TLS alert %d from the server"), last_alert);
+	}
 }
 
 ssize_t CTlsSocket::PushFunction(gnutls_transport_ptr_t ptr, const void* data, size_t len)
@@ -623,19 +629,21 @@ int CTlsSocket::ContinueHandshake()
 	if (!res) {
 		m_pOwner->LogMessage(MessageType::Debug_Info, _T("TLS Handshake successful"));
 
-		if (ResumedSession())
+		if (ResumedSession()) {
 			m_pOwner->LogMessage(MessageType::Debug_Info, _T("TLS Session resumed"));
+		}
 
-		const wxString protocol = GetProtocolName();
-		const wxString keyExchange = GetKeyExchange();
-		const wxString cipherName = GetCipherName();
-		const wxString macName = GetMacName();
+		std::wstring const protocol = GetProtocolName();
+		std::wstring const keyExchange = GetKeyExchange();
+		std::wstring const cipherName = GetCipherName();
+		std::wstring const macName = GetMacName();
 
 		m_pOwner->LogMessage(MessageType::Debug_Info, _T("Protocol: %s, Key exchange: %s, Cipher: %s, MAC: %s"), protocol, keyExchange, cipherName, macName);
 
 		res = VerifyCertificate();
-		if (res != FZ_REPLY_OK)
+		if (res != FZ_REPLY_OK) {
 			return res;
+		}
 
 		if (m_shutdown_requested) {
 			int error = Shutdown();
@@ -646,8 +654,9 @@ int CTlsSocket::ContinueHandshake()
 
 		return FZ_REPLY_OK;
 	}
-	else if (res == GNUTLS_E_AGAIN || res == GNUTLS_E_INTERRUPTED)
+	else if (res == GNUTLS_E_AGAIN || res == GNUTLS_E_INTERRUPTED) {
 		return FZ_REPLY_WOULDBLOCK;
+	}
 
 	Failure(res, true);
 
@@ -840,7 +849,7 @@ void CTlsSocket::CheckResumeFailedReadWrite()
 	}
 }
 
-void CTlsSocket::Failure(int code, bool send_close, const wxString& function)
+void CTlsSocket::Failure(int code, bool send_close, std::wstring const& function)
 {
 	m_pOwner->LogMessage(MessageType::Debug_Debug, _T("CTlsSocket::Failure(%d)"), code);
 	if (code) {
@@ -967,14 +976,16 @@ void CTlsSocket::TrustCurrentCert(bool trusted)
 	Failure(0, true);
 }
 
-static wxString bin2hex(const unsigned char* in, size_t size)
+static std::wstring bin2hex(const unsigned char* in, size_t size)
 {
-	wxString str;
-	for (size_t i = 0; i < size; i++)
-	{
-		if (i)
-			str += _T(":");
-		str += wxString::Format(_T("%.2x"), (int)in[i]);
+	std::wstring str;
+	str.reserve(size * 3);
+	for (size_t i = 0; i < size; ++i) {
+		if (i) {
+			str += ':';
+		}
+		str += fz::int_to_hex_char<wchar_t>(in[i] >> 4);
+		str += fz::int_to_hex_char<wchar_t>(in[i] & 0xf);
 	}
 
 	return str;
@@ -994,28 +1005,28 @@ bool CTlsSocket::ExtractCert(gnutls_x509_crt_t const& cert, CCertificate& out)
 		size = 0;
 	}
 
-	wxString serial = bin2hex(buffer, size);
+	std::wstring serial = bin2hex(buffer, size);
 
 	unsigned int pkBits;
 	int pkAlgo = gnutls_x509_crt_get_pk_algorithm(cert, &pkBits);
-	wxString pkAlgoName;
+	std::wstring pkAlgoName;
 	if (pkAlgo >= 0) {
 		const char* pAlgo = gnutls_pk_algorithm_get_name((gnutls_pk_algorithm_t)pkAlgo);
 		if (pAlgo) {
-			pkAlgoName = wxString(pAlgo, wxConvUTF8);
+			pkAlgoName = fz::to_wstring_from_utf8(pAlgo);
 		}
 	}
 
 	int signAlgo = gnutls_x509_crt_get_signature_algorithm(cert);
-	wxString signAlgoName;
+	std::wstring signAlgoName;
 	if (signAlgo >= 0) {
 		const char* pAlgo = gnutls_sign_algorithm_get_name((gnutls_sign_algorithm_t)signAlgo);
 		if (pAlgo) {
-			signAlgoName = wxString(pAlgo, wxConvUTF8);
+			signAlgoName = fz::to_wstring_from_utf8(pAlgo);
 		}
 	}
 
-	wxString subject, issuer;
+	std::wstring subject, issuer;
 
 	size = 0;
 	res = gnutls_x509_crt_get_dn(cert, 0, &size);
@@ -1024,7 +1035,7 @@ bool CTlsSocket::ExtractCert(gnutls_x509_crt_t const& cert, CCertificate& out)
 		dn[size] = 0;
 		if (!(res = gnutls_x509_crt_get_dn(cert, dn, &size))) {
 			dn[size] = 0;
-			subject = wxString(dn, wxConvUTF8);
+			subject = fz::to_wstring_from_utf8(dn);
 		}
 		else {
 			LogError(res, _T("gnutls_x509_crt_get_dn"));
@@ -1039,7 +1050,7 @@ bool CTlsSocket::ExtractCert(gnutls_x509_crt_t const& cert, CCertificate& out)
 		return false;
 	}
 
-	std::vector<wxString> alt_subject_names = GetCertSubjectAltNames(cert);
+	std::vector<std::wstring> alt_subject_names = GetCertSubjectAltNames(cert);
 
 	size = 0;
 	res = gnutls_x509_crt_get_issuer_dn(cert, 0, &size);
@@ -1048,7 +1059,7 @@ bool CTlsSocket::ExtractCert(gnutls_x509_crt_t const& cert, CCertificate& out)
 		dn[size] = 0;
 		if (!(res = gnutls_x509_crt_get_issuer_dn(cert, dn, &size))) {
 			dn[size] = 0;
-			issuer = wxString(dn, wxConvUTF8);
+			issuer = fz::to_wstring_from_utf8(dn);
 		}
 		else {
 			LogError(res, _T("gnutls_x509_crt_get_issuer_dn"));
@@ -1063,8 +1074,8 @@ bool CTlsSocket::ExtractCert(gnutls_x509_crt_t const& cert, CCertificate& out)
 		return false;
 	}
 
-	wxString fingerprint_sha256;
-	wxString fingerprint_sha1;
+	std::wstring fingerprint_sha256;
+	std::wstring fingerprint_sha1;
 
 	unsigned char digest[100];
 	size = sizeof(digest) - 1;
@@ -1099,9 +1110,9 @@ bool CTlsSocket::ExtractCert(gnutls_x509_crt_t const& cert, CCertificate& out)
 }
 
 
-std::vector<wxString> CTlsSocket::GetCertSubjectAltNames(gnutls_x509_crt_t cert)
+std::vector<std::wstring> CTlsSocket::GetCertSubjectAltNames(gnutls_x509_crt_t cert)
 {
-	std::vector<wxString> ret;
+	std::vector<std::wstring> ret;
 
 	char san[4096];
 	for (unsigned int i = 0; i < 10000; ++i) { // I assume this is a sane limit
@@ -1115,15 +1126,15 @@ std::vector<wxString> CTlsSocket::GetCertSubjectAltNames(gnutls_x509_crt_t cert)
 		}
 
 		if (type_or_error == GNUTLS_SAN_DNSNAME || type_or_error == GNUTLS_SAN_RFC822NAME) {
-			wxString dns = wxString(san, wxConvUTF8);
+			std::wstring dns = fz::to_wstring_from_utf8(san);
 			if (!dns.empty()) {
-				ret.push_back(dns);
+				ret.emplace_back(std::move(dns));
 			}
 		}
 		else if (type_or_error == GNUTLS_SAN_IPADDRESS) {
-			wxString ip = CSocket::AddressToString(san, san_size);
+			std::wstring ip = fz::to_wstring(CSocket::AddressToString(san, san_size));
 			if (!ip.empty()) {
-				ret.push_back(ip);
+				ret.emplace_back(std::move(ip));
 			}
 		}
 	}
@@ -1395,44 +1406,68 @@ void CTlsSocket::OnRateAvailable(CRateLimiter::rate_direction)
 {
 }
 
-wxString CTlsSocket::GetProtocolName()
+std::wstring CTlsSocket::GetProtocolName()
 {
-	wxString protocol = _("unknown");
+	std::wstring ret;
 
 	const char* s = gnutls_protocol_get_name( gnutls_protocol_get_version( m_session ) );
-	if (s && *s)
-		protocol = wxString(s, wxConvUTF8);
+	if (s && *s) {
+		ret = fz::to_wstring_from_utf8(s);
+	}
+	
+	if (ret.empty()) {
+		ret = _("unknown").ToStdWstring();
+	}
 
-	return protocol;
+	return ret;
 }
 
-wxString CTlsSocket::GetKeyExchange()
+std::wstring CTlsSocket::GetKeyExchange()
 {
-	wxString keyExchange = _("unknown");
+	std::wstring ret;
 
 	const char* s = gnutls_kx_get_name( gnutls_kx_get( m_session ) );
-	if (s && *s)
-		keyExchange = wxString(s, wxConvUTF8);
+	if (s && *s) {
+		ret = fz::to_wstring_from_utf8(s);
+	}
 
-	return keyExchange;
+	if (ret.empty()) {
+		ret = _("unknown").ToStdWstring();
+	}
+
+	return ret;
 }
 
-wxString CTlsSocket::GetCipherName()
+std::wstring CTlsSocket::GetCipherName()
 {
+	std::wstring ret;
+
 	const char* cipher = gnutls_cipher_get_name(gnutls_cipher_get(m_session));
-	if (cipher && *cipher)
-		return wxString(cipher, wxConvUTF8);
-	else
-		return _("unknown");
+	if (cipher && *cipher) {
+		ret = fz::to_wstring_from_utf8(cipher);
+	}
+
+	if (ret.empty()) {
+		ret = _("unknown").ToStdWstring();
+	}
+
+	return ret;
 }
 
-wxString CTlsSocket::GetMacName()
+std::wstring CTlsSocket::GetMacName()
 {
+	std::wstring ret;
+
 	const char* mac = gnutls_mac_get_name(gnutls_mac_get(m_session));
-	if (mac && *mac)
-		return wxString(mac, wxConvUTF8);
-	else
-		return _T("unknown");
+	if (mac && *mac) {
+		ret = fz::to_wstring_from_utf8(mac);
+	}
+	
+	if (ret.empty()) {
+		ret = _("unknown").ToStdWstring();
+	}
+
+	return ret;
 }
 
 std::string CTlsSocket::ListTlsCiphers(std::string priority)
