@@ -596,7 +596,7 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 			wxBell();
 			return;
 		}
-		pState->m_pCommandQueue->ProcessCommand(new CRawCommand(dlg.GetValue()));
+		pState->m_pCommandQueue->ProcessCommand(new CRawCommand(dlg.GetValue().ToStdWstring()));
 	}
 	else if (event.GetId() == XRCID("wxID_PREFERENCES")) {
 		OnMenuEditSettings(event);
@@ -619,6 +619,15 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 	else if (event.GetId() == XRCID("ID_CLEARCACHE_LAYOUT")) {
 		CWrapEngine::ClearCache();
 	}
+	else if (event.GetId() == XRCID("ID_CLEAR_UPDATER")) {
+#if FZ_MANUALUPDATECHECK
+		if (m_pUpdater) {
+			COptions::Get()->SetOption(OPTION_UPDATECHECK_LASTDATE, std::wstring());
+			COptions::Get()->SetOption(OPTION_UPDATECHECK_NEWVERSION, std::wstring());
+			m_pUpdater->Init();
+		}
+#endif
+	}
 	else if (event.GetId() == XRCID("ID_MENU_TRANSFER_FILEEXISTS")) {
 		CDefaultFileExistsDlg dlg;
 		if (!dlg.Load(this, false))
@@ -928,7 +937,9 @@ void CMainFrame::DoOnEngineEvent(CFileZillaEngine* engine)
 			}
 			break;
 		case nId_transferstatus:
-			m_pQueueView->ProcessNotification(pState->m_pEngine, std::move(pNotification));
+			if (m_pQueueView) {
+				m_pQueueView->ProcessNotification(pState->m_pEngine, std::move(pNotification));
+			}
 			break;
 		case nId_sftp_encryption:
 			{
@@ -1239,7 +1250,7 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 	if (controls) {
 		Site site = controls->pState->GetLastSite();
 		COptions::Get()->SetLastServer(site.m_server);
-		COptions::Get()->SetOption(OPTION_LASTSERVERPATH, controls->pState->GetLastServerPath().GetSafePath().ToStdWstring());
+		COptions::Get()->SetOption(OPTION_LASTSERVERPATH, controls->pState->GetLastServerPath().GetSafePath());
 		COptions::Get()->SetOption(OPTION_LAST_CONNECTED_SITE, site.m_path);
 	}
 
@@ -1945,7 +1956,7 @@ bool CMainFrame::ConnectToSite(Site & data, Bookmark const& bookmark)
 	// Apply comparison and sync browsing options
 	// FIXME: Move to state?
 	if (!bookmark.m_localDir.empty()) {
-		bool set = pState->SetLocalDir(bookmark.m_localDir, 0, false);
+		bool set = pState->SetLocalDir(bookmark.m_localDir.ToStdWstring(), 0, false);
 
 		if (set && bookmark.m_sync) {
 			wxASSERT(!bookmark.m_remoteDir.empty());
@@ -1967,7 +1978,9 @@ void CMainFrame::CheckChangedSettings()
 	CAutoAsciiFiles::SettingsChanged();
 
 #if FZ_MANUALUPDATECHECK
-	m_pUpdater->Init();
+	if (m_pUpdater) {
+		m_pUpdater->Init();
+	}
 #endif
 }
 
@@ -2316,7 +2329,7 @@ void CMainFrame::ProcessCommandLine()
 		return;
 	}
 
-	wxString local;
+	std::wstring local;
 	if ((local = pCommandLine->GetOption(CCommandLine::local)) != _T("")) {
 
 		if (!wxDir::Exists(local)) {
@@ -2349,20 +2362,22 @@ void CMainFrame::ProcessCommandLine()
 		}
 	}
 
-	wxString param = pCommandLine->GetParameter();
+	std::wstring param = pCommandLine->GetParameter().ToStdWstring();
 	if (!param.empty()) {
-		wxString error;
+		std::wstring error;
 
 		CServer server;
 
 		wxString logontype = pCommandLine->GetOption(CCommandLine::logontype);
-		if (logontype == _T("ask"))
+		if (logontype == _T("ask")) {
 			server.SetLogonType(ASK);
-		else if (logontype == _T("interactive"))
+		}
+		else if (logontype == _T("interactive")) {
 			server.SetLogonType(INTERACTIVE);
+		}
 
 		CServerPath path;
-		if (!server.ParseUrl(param, 0, _T(""), _T(""), error, path)) {
+		if (!server.ParseUrl(param, 0, std::wstring(), std::wstring(), error, path)) {
 			wxString str = _("Parameter not a valid URL");
 			str += _T("\n") + error;
 			wxMessageBoxEx(error, _("Syntax error in command line"));
@@ -2375,8 +2390,9 @@ void CMainFrame::ProcessCommandLine()
 		else if (server.GetLogonType() == ASK ||
 			(server.GetLogonType() == INTERACTIVE && server.GetUser().empty()))
 		{
-			if (!CLoginManager::Get().GetPassword(server, false))
+			if (!CLoginManager::Get().GetPassword(server, false)) {
 				return;
+			}
 		}
 
 		Site site;
