@@ -115,30 +115,32 @@ public:
 		}
 
 		// Find drop directory (if it exists)
-		wxString subdir;
+		std::wstring subdir;
 		int flags = 0;
 		int hit = m_pRemoteListView->HitTest(wxPoint(x, y), flags, 0);
-		if (hit != -1 && (flags & wxLIST_HITTEST_ONITEM))
-		{
+		if (hit != -1 && (flags & wxLIST_HITTEST_ONITEM)) {
 			int index = m_pRemoteListView->GetItemIndex(hit);
 			if (index != -1 && m_pRemoteListView->m_fileData[index].comparison_flags != CComparableListing::fill)
 			{
-				if (index == (int)m_pRemoteListView->m_pDirectoryListing->GetCount())
+				if (index == (int)m_pRemoteListView->m_pDirectoryListing->GetCount()) {
 					subdir = _T("..");
-				else if ((*m_pRemoteListView->m_pDirectoryListing)[index].is_dir())
+				}
+				else if ((*m_pRemoteListView->m_pDirectoryListing)[index].is_dir()) {
 					subdir = (*m_pRemoteListView->m_pDirectoryListing)[index].name;
+				}
 			}
 		}
 
 		// Get target path
 		CServerPath target = m_pRemoteListView->m_pDirectoryListing->path;
-		if (subdir == _T(".."))
-		{
-			if (target.HasParent())
+		if (subdir == _T("..")) {
+			if (target.HasParent()) {
 				target = target.GetParent();
+			}
 		}
-		else if (!subdir.empty())
+		else if (!subdir.empty()) {
 			target.AddSegment(subdir);
+		}
 
 		// Make sure target path is valid
 		if (target == m_pRemoteDataObject->GetServerPath())
@@ -865,25 +867,26 @@ void CRemoteListView::SetDirectoryListing(std::shared_ptr<CDirectoryListing> con
 // foo.bar;1
 // foo.bar;2
 // foo.bar;3
-wxString StripVMSRevision(const wxString& name)
+std::wstring StripVMSRevision(std::wstring const& name)
 {
-	int pos = name.Find(';', true);
-	if (pos < 1)
+	size_t pos = name.rfind(';');
+	if (pos == std::wstring::npos || !pos) {
 		return name;
-
-	const int len = name.Len();
-	if (pos == len - 1)
-		return name;
-
-	int p = pos;
-	while (++p < len)
-	{
-		const wxChar& c = name[p];
-		if (c < '0' || c > '9')
-			return name;
 	}
 
-	return name.Left(pos);
+	if (pos == name.size() - 1) {
+		return name;
+	}
+
+	size_t p = pos;
+	while (++p < name.size()) {
+		wchar_t const& c = name[p];
+		if (c < '0' || c > '9') {
+			return name;
+		}
+	}
+
+	return name.substr(0, pos);
 }
 
 
@@ -937,8 +940,8 @@ void CRemoteListView::OnItemActivated(wxListEvent &event)
 		if (m_fileData[index].comparison_flags == fill)
 			return;
 
-		const CDirentry& entry = (*m_pDirectoryListing)[index];
-		const wxString& name = entry.name;
+		CDirentry const& entry = (*m_pDirectoryListing)[index];
+		std::wstring const& name = entry.name;
 
 		const CServer* pServer = m_state.GetServer();
 		if (!pServer) {
@@ -991,11 +994,11 @@ void CRemoteListView::OnItemActivated(wxListEvent &event)
 				return;
 			}
 
-			wxString localFile = CQueueView::ReplaceInvalidCharacters(name);
+			std::wstring localFile = CQueueView::ReplaceInvalidCharacters(name);
 			if (m_pDirectoryListing->path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
 				localFile = StripVMSRevision(localFile);
 			m_pQueue->QueueFile(queue_only, true, name,
-				(name == localFile) ? wxString() : localFile,
+				(name == localFile) ? std::wstring() : localFile,
 				local_path, m_pDirectoryListing->path, *pServer, entry.size);
 			m_pQueue->QueueFile_Finish(true);
 		}
@@ -1030,8 +1033,8 @@ void CRemoteListView::OnMenuEnter(wxCommandEvent &)
 			return;
 		}
 
-		const CDirentry& entry = (*m_pDirectoryListing)[index];
-		const wxString& name = entry.name;
+		CDirentry const& entry = (*m_pDirectoryListing)[index];
+		std::wstring const& name = entry.name;
 
 		const CServer* pServer = m_state.GetServer();
 		if (!pServer) {
@@ -1054,7 +1057,7 @@ void CRemoteListView::OnMenuEnter(wxCommandEvent &)
 		m_state.ChangeRemoteDir(m_pDirectoryListing->path, name, entry.is_link() ? LIST_FLAG_LINK : 0);
 	}
 	else {
-		m_state.ChangeRemoteDir(m_pDirectoryListing->path, _T(".."));
+		m_state.ChangeRemoteDir(m_pDirectoryListing->path, L"..");
 	}
 }
 
@@ -1242,8 +1245,8 @@ void CRemoteListView::TransferSelectedFiles(const CLocalPath& local_parent, bool
 		if (m_fileData[index].comparison_flags == fill)
 			continue;
 
-		const CDirentry& entry = (*m_pDirectoryListing)[index];
-		const wxString& name = entry.name;
+		CDirentry const& entry = (*m_pDirectoryListing)[index];
+		std::wstring const& name = entry.name;
 
 		if (entry.is_dir()) {
 			if (!idle)
@@ -1256,11 +1259,12 @@ void CRemoteListView::TransferSelectedFiles(const CLocalPath& local_parent, bool
 			}
 		}
 		else {
-			wxString localFile = CQueueView::ReplaceInvalidCharacters(name);
-			if (m_pDirectoryListing->path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
+			std::wstring localFile = CQueueView::ReplaceInvalidCharacters(name);
+			if (m_pDirectoryListing->path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION)) {
 				localFile = StripVMSRevision(localFile);
+			}
 			m_pQueue->QueueFile(queue_only, true,
-				name, (name == localFile) ? wxString() : localFile,
+				name, (name == localFile) ? std::wstring() : localFile,
 				local_parent, m_pDirectoryListing->path, *pServer, entry.size);
 			added = true;
 		}
@@ -1286,7 +1290,7 @@ void CRemoteListView::OnMenuMkdirChgDir(wxCommandEvent&)
 {
 	CServerPath newdir = MenuMkdir();
 	if (!newdir.empty()) {
-		m_state.ChangeRemoteDir(newdir, wxString(), 0, true);
+		m_state.ChangeRemoteDir(newdir, std::wstring(), 0, true);
 	}
 }
 
@@ -1308,7 +1312,7 @@ CServerPath CRemoteListView::MenuMkdir()
 	// Append a long segment which does (most likely) not exist in the path and
 	// replace it with "New directory" later. This way we get the exact position of
 	// "New directory" and can preselect it in the dialog.
-	wxString tmpName = _T("25CF809E56B343b5A12D1F0466E3B37A49A9087FDCF8412AA9AF8D1E849D01CF");
+	std::wstring tmpName = _T("25CF809E56B343b5A12D1F0466E3B37A49A9087FDCF8412AA9AF8D1E849D01CF");
 	if (path.AddSegment(tmpName)) {
 		wxString pathName = path.GetPath();
 		int pos = pathName.Find(tmpName);
@@ -1332,7 +1336,7 @@ CServerPath CRemoteListView::MenuMkdir()
 	}
 
 	path = m_pDirectoryListing->path;
-	if (!path.ChangePath(dlg.GetValue())) {
+	if (!path.ChangePath(dlg.GetValue().ToStdWstring())) {
 		wxBell();
 		return CServerPath();
 	}
@@ -1568,44 +1572,41 @@ bool CRemoteListView::OnBeginRename(const wxListEvent& event)
 
 bool CRemoteListView::OnAcceptRename(const wxListEvent& event)
 {
-	if (!m_state.IsRemoteIdle())
-	{
+	if (!m_state.IsRemoteIdle()) {
 		wxBell();
 		return false;
 	}
 
-	if (!m_pDirectoryListing)
-	{
+	if (!m_pDirectoryListing) {
 		wxBell();
 		return false;
 	}
 
 	int item = event.GetIndex();
-	if (!item)
+	if (!item) {
 		return false;
+	}
 
 	int index = GetItemIndex(item);
-	if (index == -1 || m_fileData[index].comparison_flags == fill)
-	{
+	if (index == -1 || m_fileData[index].comparison_flags == fill) {
 		wxBell();
 		return false;
 	}
 
 	const CDirentry& entry = (*m_pDirectoryListing)[index];
 
-	wxString newFile = event.GetLabel();
+	std::wstring newFile = event.GetLabel().ToStdWstring();
 
 	CServerPath newPath = m_pDirectoryListing->path;
-	if (!newPath.ChangePath(newFile, true))
-	{
+	if (!newPath.ChangePath(newFile, true)) {
 		wxMessageBoxEx(_("Filename invalid"), _("Cannot rename file"), wxICON_EXCLAMATION);
 		return false;
 	}
 
-	if (newPath == m_pDirectoryListing->path)
-	{
-		if (entry.name == newFile)
+	if (newPath == m_pDirectoryListing->path) {
+		if (entry.name == newFile) {
 			return false;
+		}
 
 		// Check if target file already exists
 		for (unsigned int i = 0; i < m_pDirectoryListing->GetCount(); i++)
@@ -1733,7 +1734,7 @@ void CRemoteListView::OnMenuChmod(wxCommandEvent&)
 		{
 			char newPermissions[9]{};
 			bool res = pChmodDlg->ConvertPermissions(*entry.permissions, newPermissions);
-			wxString newPerms = pChmodDlg->GetPermissions(res ? newPermissions : 0, entry.is_dir());
+			std::wstring const newPerms = pChmodDlg->GetPermissions(res ? newPermissions : 0, entry.is_dir()).ToStdWstring();
 
 			m_state.m_pCommandQueue->ProcessCommand(new CChmodCommand(m_pDirectoryListing->path, entry.name, newPerms));
 		}
@@ -2010,7 +2011,7 @@ void CRemoteListView::OnStateChange(t_statechange_notifications notification, co
 		SetDirectoryListing(m_state.GetRemoteDir());
 	else if (notification == STATECHANGE_REMOTE_LINKNOTDIR) {
 		wxASSERT(data2);
-		LinkIsNotDir(*(CServerPath*)data2, data);
+		LinkIsNotDir(*(CServerPath*)data2, data.ToStdWstring());
 	}
 	else if (notification == STATECHANGE_SERVER) {
 		m_windowTinter->SetBackgroundTint(m_state.GetSite().m_colour);
@@ -2190,7 +2191,7 @@ void CRemoteListView::OnBeginDrag(wxListEvent&)
 				}
 			}
 
-			CLocalPath target(ext->GetTarget());
+			CLocalPath target(ext->GetTarget().ToStdWstring());
 			if (target.empty()) {
 				ext.reset(); // Release extension before the modal message box
 				wxMessageBoxEx(_("Could not determine the target of the Drag&Drop operation.\nEither the shell extension is not installed properly or you didn't drop the files into an Explorer window."));
@@ -2478,14 +2479,14 @@ int64_t CRemoteListView::ItemGetSize(int index) const
 	return (*m_pDirectoryListing)[index].size;
 }
 
-void CRemoteListView::LinkIsNotDir(const CServerPath& path, const wxString& link)
+void CRemoteListView::LinkIsNotDir(CServerPath const& path, std::wstring const& link)
 {
 	if (m_pLinkResolveState && m_pLinkResolveState->remote_path == path && m_pLinkResolveState->link == link) {
-		wxString localFile = CQueueView::ReplaceInvalidCharacters(link);
+		std::wstring localFile = CQueueView::ReplaceInvalidCharacters(link);
 		if (m_pDirectoryListing->path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
 			localFile = StripVMSRevision(localFile);
 		m_pQueue->QueueFile(false, true,
-			link, (link != localFile) ? localFile : wxString(),
+			link, (link != localFile) ? localFile : std::wstring(),
 			m_pLinkResolveState->local_path, m_pLinkResolveState->remote_path, m_pLinkResolveState->server, -1);
 		m_pQueue->QueueFile_Finish(true);
 	}
@@ -2535,10 +2536,10 @@ void CRemoteListView::OnMenuGeturl(wxCommandEvent& event)
 
 	wxString const server = pServer->Format((event.GetId() == XRCID("ID_GETURL_PASSWORD")) ? ServerFormat::url_with_password : ServerFormat::url);
 
-	auto getUrl = [](wxString const& serverPart, CServerPath const& path, wxString const& name) {
+	auto getUrl = [](wxString const& serverPart, CServerPath const& path, std::wstring const& name) {
 		wxString url = serverPart;
 
-		auto const pathPart = url_encode(path.FormatFilename(name, false).ToStdWstring(), true);
+		auto const pathPart = url_encode(path.FormatFilename(name, false), true);
 		if (!pathPart.empty() && pathPart[0] != '/') {
 			url += '/';
 		}
