@@ -105,27 +105,22 @@ public:
 				return wxDragNone;
 			}
 
-			const std::list<CRemoteDataObject::t_fileInfo>& files = m_pRemoteDataObject->GetFiles();
-			for (std::list<CRemoteDataObject::t_fileInfo>::const_iterator iter = files.begin(); iter != files.end(); ++iter)
-			{
-				const CRemoteDataObject::t_fileInfo& info = *iter;
-				if (info.dir)
-				{
+			std::list<CRemoteDataObject::t_fileInfo> const& files = m_pRemoteDataObject->GetFiles();
+			for (auto const& info : files) {
+				if (info.dir) {
 					CServerPath dir = m_pRemoteDataObject->GetServerPath();
 					dir.AddSegment(info.name);
-					if (dir == path)
+					if (dir == path) {
 						return wxDragNone;
-					else if (dir.IsParentOf(path, false))
-					{
+					}
+					else if (dir.IsParentOf(path, false)) {
 						wxMessageBoxEx(_("A directory cannot be dragged into one of its subdirectories."));
 						return wxDragNone;
 					}
 				}
 			}
 
-			for (std::list<CRemoteDataObject::t_fileInfo>::const_iterator iter = files.begin(); iter != files.end(); ++iter)
-			{
-				const CRemoteDataObject::t_fileInfo& info = *iter;
+			for (auto const& info : files) {
 				m_pRemoteTreeView->m_state.m_pCommandQueue->ProcessCommand(
 					new CRenameCommand(m_pRemoteDataObject->GetServerPath(), info.name, path, info.name)
 					);
@@ -391,8 +386,9 @@ wxTreeItemId CRemoteTreeView::MakeParent(CServerPath path, bool select)
 	wxTreeItemId parent = root;
 
 	for (std::vector<wxString>::const_reverse_iterator iter = pieces.rbegin(); iter != pieces.rend(); ++iter) {
-		if (iter != pieces.rbegin())
-			path.AddSegment(*iter);
+		if (iter != pieces.rbegin()) {
+			path.AddSegment(iter->ToStdWstring());
+		}
 
 		wxTreeItemIdValue cookie;
 		wxTreeItemId child = GetFirstChild(parent, cookie);
@@ -536,7 +532,7 @@ void CRemoteTreeView::DisplayItem(wxTreeItemId parent, const CDirectoryListing&
 		if (filter.FilenameFiltered(listing[i].name, path, true, -1, false, 0, listing[i].time))
 			continue;
 
-		const wxString& name = listing[i].name;
+		std::wstring const& name = listing[i].name;
 		CServerPath subdir = listing.path;
 		subdir.AddSegment(name);
 
@@ -572,13 +568,15 @@ void CRemoteTreeView::RefreshItem(wxTreeItemId parent, const CDirectoryListing&
 
 	wxString const path = listing.path.GetPath();
 
-	std::vector<wxString> dirs;
+	std::vector<std::wstring> dirs;
 	for (unsigned int i = 0; i < listing.GetCount(); ++i) {
-		if (!listing[i].is_dir())
+		if (!listing[i].is_dir()) {
 			continue;
+		}
 
-		if (!filter.FilenameFiltered(listing[i].name, path, true, -1, false, 0, listing[i].time))
+		if (!filter.FilenameFiltered(listing[i].name, path, true, -1, false, 0, listing[i].time)) {
 			dirs.push_back(listing[i].name);
+		}
 	}
 
 	auto const& sortFunc = CFileListCtrlSortBase::GetCmpFunction(m_nameSortMode);
@@ -588,7 +586,7 @@ void CRemoteTreeView::RefreshItem(wxTreeItemId parent, const CDirectoryListing&
 	child = GetLastChild(parent);
 	auto iter = dirs.rbegin();
 	while (child && iter != dirs.rend()) {
-		int cmp = sortFunc(GetItemText(child), *iter);
+		int cmp = sortFunc(GetItemText(child).ToStdWstring(), *iter);
 
 		if (!cmp) {
 			CServerPath childPath = listing.path;
@@ -596,12 +594,14 @@ void CRemoteTreeView::RefreshItem(wxTreeItemId parent, const CDirectoryListing&
 
 			CDirectoryListing subListing;
 			if (m_state.m_pEngine->CacheLookup(childPath, subListing) == FZ_REPLY_OK) {
-				if (!GetLastChild(child) && HasSubdirs(subListing, filter))
+				if (!GetLastChild(child) && HasSubdirs(subListing, filter)) {
 					AppendItem(child, _T(""), -1, -1);
+				}
 				SetItemImages(child, false);
 			}
-			else
+			else {
 				SetItemImages(child, true);
+			}
 
 			child = GetPrevSibling(child);
 			++iter;
@@ -759,16 +759,14 @@ CServerPath CRemoteTreeView::GetPathFromItem(const wxTreeItemId& item) const
 	std::list<wxString> segments;
 
 	wxTreeItemId i = item;
-	while (i != GetRootItem())
-	{
+	while (i != GetRootItem()) {
 		const CItemData* const pData = (const CItemData*)GetItemData(i);
-		if (pData)
-		{
+		if (pData) {
 			CServerPath path = pData->m_path;
-			for (std::list<wxString>::const_iterator iter = segments.begin(); iter != segments.end(); ++iter)
-			{
-				if (!path.AddSegment(*iter))
+			for (std::list<wxString>::const_iterator iter = segments.begin(); iter != segments.end(); ++iter) {
+				if (!path.AddSegment(iter->ToStdWstring())) {
 					return CServerPath();
+				}
 			}
 			return path;
 		}
@@ -859,7 +857,7 @@ void CRemoteTreeView::OnBeginDrag(wxTreeEvent& event)
 				return;
 			}
 
-			CLocalPath target(ext->GetTarget());
+			CLocalPath target(ext->GetTarget().ToStdWstring());
 			if (target.empty()) {
 				ext.reset(); // Release extension before the modal message box
 				wxMessageBoxEx(_("Could not determine the target of the Drag&Drop operation.\nEither the shell extension is not installed properly or you didn't drop the files into an Explorer window."));
@@ -906,22 +904,25 @@ void CRemoteTreeView::OnContextMenu(wxTreeEvent& event)
 
 void CRemoteTreeView::OnMenuChmod(wxCommandEvent&)
 {
-	if (!m_state.IsRemoteIdle())
+	if (!m_state.IsRemoteIdle()) {
 		return;
+	}
 
-	if (!m_contextMenuItem)
+	if (!m_contextMenuItem) {
 		return;
+	}
 
 	const CServerPath& path = GetPathFromItem(m_contextMenuItem);
-	if (path.empty())
+	if (path.empty()) {
 		return;
+	}
 
 	const bool hasParent = path.HasParent();
 
 	CChmodDialog* pChmodDlg = new CChmodDialog;
 
 	// Get current permissions of directory
-	const wxString& name = GetItemText(m_contextMenuItem);
+	std::wstring const name = GetItemText(m_contextMenuItem).ToStdWstring();
 	char permissions[9] = {0};
 	bool cached = false;
 
@@ -934,8 +935,9 @@ void CRemoteTreeView::OnMenuChmod(wxCommandEvent&)
 		cached = m_state.m_pEngine->CacheLookup(parentPath, listing) == FZ_REPLY_OK;
 		if (cached) {
 			for (unsigned int i = 0; i < listing.GetCount(); ++i) {
-				if (listing[i].name != name)
+				if (listing[i].name != name) {
 					continue;
+				}
 
 				pChmodDlg->ConvertPermissions(*listing[i].permissions, permissions);
 			}
@@ -967,20 +969,23 @@ void CRemoteTreeView::OnMenuChmod(wxCommandEvent&)
 	if (cached) { // Implies hasParent
 		// Change directory permissions
 		if (!applyType || applyType == 2) {
-			wxString newPerms = pChmodDlg->GetPermissions(permissions, true);
+			std::wstring const newPerms = pChmodDlg->GetPermissions(permissions, true).ToStdWstring();
 
 			m_state.m_pCommandQueue->ProcessCommand(new CChmodCommand(path.GetParent(), name, newPerms));
 		}
 
-		if (pChmodDlg->Recursive())
+		if (pChmodDlg->Recursive()) {
 			// Start recursion
-			root.add_dir_to_visit(path, _T(""), CLocalPath());
+			root.add_dir_to_visit(path, std::wstring(), CLocalPath());
+		}
 	}
 	else {
-		if (hasParent)
+		if (hasParent) {
 			root.add_dir_to_visit_restricted(path.GetParent(), name, pChmodDlg->Recursive());
-		else
-			root.add_dir_to_visit_restricted(path, _T(""), pChmodDlg->Recursive());
+		}
+		else {
+			root.add_dir_to_visit_restricted(path, std::wstring(), pChmodDlg->Recursive());
+		}
 	}
 
 	if (!cached || pChmodDlg->Recursive()) {
@@ -993,7 +998,7 @@ void CRemoteTreeView::OnMenuChmod(wxCommandEvent&)
 		if (selected)
 			currentPath = GetPathFromItem(selected);
 		CFilterManager filter;
-		pRecursiveOperation->StartRecursiveOperation(CRecursiveOperation::recursive_chmod, filter.GetActiveFilters(false), currentPath);
+		pRecursiveOperation->StartRecursiveOperation(CRecursiveOperation::recursive_chmod, filter.GetActiveFilters(), currentPath);
 	}
 	else {
 		pChmodDlg->Destroy();
@@ -1013,33 +1018,37 @@ void CRemoteTreeView::OnMenuDownload(wxCommandEvent& event)
 		return;
 	}
 
-	if (!m_state.IsRemoteIdle())
+	if (!m_state.IsRemoteIdle()) {
 		return;
+	}
 
-	if (!m_contextMenuItem)
+	if (!m_contextMenuItem) {
 		return;
+	}
 
 	const CServerPath& path = GetPathFromItem(m_contextMenuItem);
-	if (path.empty())
+	if (path.empty()) {
 		return;
+	}
 
-	const wxString& name = GetItemText(m_contextMenuItem);
+	std::wstring const name = GetItemText(m_contextMenuItem).ToStdWstring();
 
 	localDir.AddSegment(CQueueView::ReplaceInvalidCharacters(name));
 
 	recursion_root root(path, true);
-	root.add_dir_to_visit(path, _T(""), localDir);
+	root.add_dir_to_visit(path, std::wstring(), localDir);
 	CRemoteRecursiveOperation* pRecursiveOperation = m_state.GetRemoteRecursiveOperation();
 	pRecursiveOperation->AddRecursionRoot(std::move(root));
 
 	CServerPath currentPath;
 	const wxTreeItemId selected = GetSelection();
-	if (selected)
+	if (selected) {
 		currentPath = GetPathFromItem(selected);
+	}
 
 	const bool addOnly = event.GetId() == XRCID("ID_ADDTOQUEUE");
 	CFilterManager filter;
-	pRecursiveOperation->StartRecursiveOperation(addOnly ? CRecursiveOperation::recursive_addtoqueue : CRecursiveOperation::recursive_transfer, filter.GetActiveFilters(false), currentPath);
+	pRecursiveOperation->StartRecursiveOperation(CRecursiveOperation::recursive_transfer, filter.GetActiveFilters(), currentPath, !addOnly);
 }
 
 void CRemoteTreeView::OnMenuDelete(wxCommandEvent&)
@@ -1064,7 +1073,7 @@ void CRemoteTreeView::OnMenuDelete(wxCommandEvent&)
 	recursion_root root;
 	CServerPath startDir;
 	if (hasParent) {
-		const wxString& name = GetItemText(m_contextMenuItem);
+		std::wstring const name = GetItemText(m_contextMenuItem).ToStdWstring();
 		startDir = pathToDelete.GetParent();
 		root = recursion_root(startDir, !hasParent);
 		root.add_dir_to_visit(startDir, name);
@@ -1072,7 +1081,7 @@ void CRemoteTreeView::OnMenuDelete(wxCommandEvent&)
 	else {
 		startDir = pathToDelete;
 		root = recursion_root(startDir, !hasParent);
-		root.add_dir_to_visit(startDir, _T(""));
+		root.add_dir_to_visit(startDir, std::wstring());
 	}
 	pRecursiveOperation->AddRecursionRoot(std::move(root));
 
@@ -1086,7 +1095,7 @@ void CRemoteTreeView::OnMenuDelete(wxCommandEvent&)
 	}
 
 	CFilterManager filter;
-	pRecursiveOperation->StartRecursiveOperation(CRecursiveOperation::recursive_delete, filter.GetActiveFilters(false), currentPath);
+	pRecursiveOperation->StartRecursiveOperation(CRecursiveOperation::recursive_delete, filter.GetActiveFilters(), currentPath);
 }
 
 void CRemoteTreeView::OnMenuRename(wxCommandEvent&)
@@ -1147,8 +1156,8 @@ void CRemoteTreeView::OnEndLabelEdit(wxTreeEvent& event)
 	CServerPath old_path = GetPathFromItem(event.GetItem());
 	CServerPath parent = old_path.GetParent();
 
-	const wxString& oldName = GetItemText(event.GetItem());
-	const wxString& newName = event.GetLabel();
+	std::wstring const oldName = GetItemText(event.GetItem()).ToStdWstring();
+	std::wstring const newName = event.GetLabel().ToStdWstring();
 	if (oldName == newName) {
 		event.Veto();
 		return;
@@ -1159,10 +1168,12 @@ void CRemoteTreeView::OnEndLabelEdit(wxTreeEvent& event)
 
 	CServerPath currentPath;
 	const wxTreeItemId selected = GetSelection();
-	if (selected)
+	if (selected) {
 		currentPath = GetPathFromItem(selected);
-	if (currentPath.empty())
+	}
+	if (currentPath.empty()) {
 		return;
+	}
 
 	if (currentPath == old_path || currentPath.IsSubdirOf(old_path, false)) {
 		// Previously selected path was below renamed one, list the new one
@@ -1178,12 +1189,14 @@ void CRemoteTreeView::OnEndLabelEdit(wxTreeEvent& event)
 		}
 		currentPath = parent;
 		currentPath.AddSegment(newName);
-		for (std::list<wxString>::const_iterator iter = subdirs.begin(); iter != subdirs.end(); ++iter)
-			currentPath.AddSegment(*iter);
+		for (std::list<wxString>::const_iterator iter = subdirs.begin(); iter != subdirs.end(); ++iter) {
+			currentPath.AddSegment(iter->ToStdWstring());
+		}
 		m_state.ChangeRemoteDir(currentPath);
 	}
-	else if (currentPath != parent)
+	else if (currentPath != parent) {
 		m_state.ChangeRemoteDir(currentPath);
+	}
 }
 
 
@@ -1240,7 +1253,7 @@ CServerPath CRemoteTreeView::MenuMkdir()
 	// Append a long segment which does (most likely) not exist in the path and
 	// replace it with "New directory" later. This way we get the exact position of
 	// "New directory" and can preselect it in the dialog.
-	wxString tmpName = _T("25CF809E56B343b5A12D1F0466E3B37A49A9087FDCF8412AA9AF8D1E849D01CF");
+	std::wstring tmpName = _T("25CF809E56B343b5A12D1F0466E3B37A49A9087FDCF8412AA9AF8D1E849D01CF");
 	if (newPath.AddSegment(tmpName)) {
 		wxString pathName = newPath.GetPath();
 		int pos = pathName.Find(tmpName);
@@ -1255,7 +1268,7 @@ CServerPath CRemoteTreeView::MenuMkdir()
 		return CServerPath();
 
 	newPath = path;
-	if (!newPath.ChangePath(dlg.GetValue())) {
+	if (!newPath.ChangePath(dlg.GetValue().ToStdWstring())) {
 		wxBell();
 		return CServerPath();
 	}
@@ -1341,7 +1354,7 @@ void CRemoteTreeView::ApplyFilters(bool resort)
 				if (path.empty())
 					continue;
 
-				if (filter.FilenameFiltered(GetItemText(child), path.GetPath(), true, -1, false, 0, fz::datetime())) {
+				if (filter.FilenameFiltered(GetItemText(child).ToStdWstring(), path.GetPath(), true, -1, false, 0, fz::datetime())) {
 					wxTreeItemId sel = GetSelection();
 					while (sel && sel != child)
 						sel = GetItemParent(sel);
@@ -1397,7 +1410,7 @@ void CRemoteTreeView::OnMenuGeturl(wxCommandEvent& event)
 
 	wxString url = pServer->Format((event.GetId() == XRCID("ID_GETURL_PASSWORD")) ? ServerFormat::url_with_password : ServerFormat::url);
 
-	wxString const pathPart = url_encode(path.GetPath().ToStdWstring(), true);
+	std::wstring const pathPart = url_encode(path.GetPath(), true);
 	if (!pathPart.empty() && pathPart[0] != '/') {
 		url += '/';
 	}
