@@ -8,7 +8,7 @@ BEGIN_EVENT_TABLE(CConditionalDialog, wxDialog)
 EVT_BUTTON(wxID_ANY, CConditionalDialog::OnButton)
 END_EVENT_TABLE()
 
-CConditionalDialog::CConditionalDialog(wxWindow* parent, enum DialogType type, enum Modes mode, bool checked /*=false*/)
+CConditionalDialog::CConditionalDialog(wxWindow* parent, DialogType type, Modes mode, bool checked /*=false*/)
 	: wxDialog(parent, wxID_ANY, _T(""), wxDefaultPosition), m_type(type)
 {
 	wxSizer* pVertSizer = new wxBoxSizer(wxVERTICAL);
@@ -70,7 +70,7 @@ bool CConditionalDialog::Run()
 		while (dialogs.Len() <= (unsigned int)m_type)
 			dialogs += _T("0");
 		dialogs[m_type] = '1';
-		COptions::Get()->SetOption(OPTION_ONETIME_DIALOGS, dialogs);
+		COptions::Get()->SetOption(OPTION_ONETIME_DIALOGS, dialogs.ToStdWstring());
 	}
 
 	if (id == wxID_OK || id == wxID_YES)
