@@ -4,7 +4,7 @@
 #include "dialogex.h"
 
 class CFileExistsDlg: public wxDialogEx
-{	
+{
 	DECLARE_EVENT_TABLE()
 
 public:
@@ -14,25 +14,27 @@ public:
 	/// Creation
 	bool Create(wxWindow* parent);
 
-	/// Creates the controls and sizers
-	void CreateControls();
-	
-	int GetAction() const;
+	CFileExistsNotification::OverwriteAction GetAction() const;
 	bool Always(bool &directionOnly, bool &queueOnly) const;
 
 protected:
-	virtual void OnOK(wxCommandEvent& event);
-	virtual void OnCancel(wxCommandEvent& event);
-	
+	/// Creates the controls and sizers
+	bool CreateControls();
+
+	void DisplayFile(bool left, wxString name, int64_t size, fz::datetime const& time, wxString const& iconFile);
+
+	void OnOK(wxCommandEvent& event);
+	void OnCancel(wxCommandEvent& event);
+	void OnCheck(wxCommandEvent& event);
+
 	void LoadIcon(int id, const wxString &file);
 	wxString GetPathEllipsis(wxString path, wxWindow *window);
 
 	CFileExistsNotification *m_pNotification;
-	wxRadioButton *m_pAction1, *m_pAction2, *m_pAction3, *m_pAction4, *m_pAction5;
-	int m_action;
-	bool m_always;
-	bool m_directionOnly;
-	bool m_queueOnly;
+	CFileExistsNotification::OverwriteAction m_action;
+	bool m_always{};
+	bool m_directionOnly{};
+	bool m_queueOnly{};
 };
 
 #endif //__FILEEXISTSDLG_H__
