@@ -955,7 +955,7 @@ bool CSiteManagerDialog::Verify()
 		return true;
 
 	if (data->m_site) {
-		const wxString& host = XRCCTRL(*this, "ID_HOST", wxTextCtrl)->GetValue();
+		std::wstring const host = xrc_call(*this, "ID_HOST", &wxTextCtrl::GetValue).ToStdWstring();
 		if (host.empty()) {
 			XRCCTRL(*this, "ID_HOST", wxTextCtrl)->SetFocus();
 			wxMessageBoxEx(_("You have to enter a hostname."), _("Site Manager - Invalid data"), wxICON_EXCLAMATION, this);
@@ -998,10 +998,10 @@ bool CSiteManagerDialog::Verify()
 		server.SetLogonType(logon_type);
 		server.SetProtocol(protocol);
 
-		wxString port = XRCCTRL(*this, "ID_PORT", wxTextCtrl)->GetValue();
+		std::wstring port = xrc_call(*this, "ID_PORT", &wxTextCtrl::GetValue).ToStdWstring();
 		CServerPath path;
-		wxString error;
-		if (!server.ParseUrl(host, port, wxString(), wxString(), error, path)) {
+		std::wstring error;
+		if (!server.ParseUrl(host, port, std::wstring(), std::wstring(), error, path)) {
 			XRCCTRL(*this, "ID_HOST", wxTextCtrl)->SetFocus();
 			wxMessageBoxEx(error, _("Site Manager - Invalid data"), wxICON_EXCLAMATION, this);
 			return false;
@@ -1063,9 +1063,9 @@ bool CSiteManagerDialog::Verify()
 		}
 
 		// In key file logon type, check that the provided key file exists
-		wxString keyFile, keyFileComment, keyFileData;
+		std::wstring keyFile, keyFileComment, keyFileData;
 		if (logon_type == KEY) {
-			keyFile = xrc_call(*this, "ID_KEYFILE", &wxTextCtrl::GetValue);
+			keyFile = xrc_call(*this, "ID_KEYFILE", &wxTextCtrl::GetValue).ToStdWstring();
 			if (keyFile.empty()) {
 				wxMessageBox(_("You have to enter a key file path"), _("Site Manager - Invalid data"), wxICON_EXCLAMATION, this);
 				xrc_call(*this, "ID_KEYFILE", &wxWindow::SetFocus);
@@ -1074,29 +1074,29 @@ bool CSiteManagerDialog::Verify()
 
 			// Check (again) that the key file is in the correct format since it might have been introduced manually
 			CFZPuttyGenInterface cfzg(this);
-			if (cfzg.LoadKeyFile(keyFile, false, keyFileComment, keyFileData))
+			if (cfzg.LoadKeyFile(keyFile, false, keyFileComment, keyFileData)) {
 				xrc_call(*this, "ID_KEYFILE", &wxTextCtrl::ChangeValue, keyFile);
+			}
 			else {
 				xrc_call(*this, "ID_KEYFILE", &wxWindow::SetFocus);
 				return false;
 			}
 		}
 
-		const wxString remotePathRaw = XRCCTRL(*this, "ID_REMOTEDIR", wxTextCtrl)->GetValue();
+		std::wstring const remotePathRaw = XRCCTRL(*this, "ID_REMOTEDIR", wxTextCtrl)->GetValue().ToStdWstring();
 		if (!remotePathRaw.empty()) {
-			const wxString serverType = XRCCTRL(*this, "ID_SERVERTYPE", wxChoice)->GetStringSelection();
+			std::wstring serverType = XRCCTRL(*this, "ID_SERVERTYPE", wxChoice)->GetStringSelection().ToStdWstring();
 
 			CServerPath remotePath;
 			remotePath.SetType(CServer::GetServerTypeFromName(serverType));
-			if (!remotePath.SetPath(remotePathRaw))
-			{
+			if (!remotePath.SetPath(remotePathRaw)) {
 				XRCCTRL(*this, "ID_REMOTEDIR", wxTextCtrl)->SetFocus();
 				wxMessageBoxEx(_("Default remote path cannot be parsed. Make sure it is a valid absolute path for the selected server type."), _("Site Manager - Invalid data"), wxICON_EXCLAMATION, this);
 				return false;
 			}
 		}
 
-		const wxString localPath = XRCCTRL(*this, "ID_LOCALDIR", wxTextCtrl)->GetValue();
+		std::wstring const localPath = XRCCTRL(*this, "ID_LOCALDIR", wxTextCtrl)->GetValue().ToStdWstring();
 		if (XRCCTRL(*this, "ID_SYNC", wxCheckBox)->GetValue()) {
 			if (remotePathRaw.empty() || localPath.empty()) {
 				XRCCTRL(*this, "ID_SYNC", wxCheckBox)->SetFocus();
@@ -1119,7 +1119,7 @@ bool CSiteManagerDialog::Verify()
 		if (!remotePathRaw.empty()) {
 			CServerPath remotePath;
 			remotePath.SetType(pServer->m_site->m_server.GetType());
-			if (!remotePath.SetPath(remotePathRaw)) {
+			if (!remotePath.SetPath(remotePathRaw.ToStdWstring())) {
 				XRCCTRL(*this, "ID_BOOKMARK_REMOTEDIR", wxTextCtrl)->SetFocus();
 				wxString msg;
 				if (pServer->m_site->m_server.GetType() != DEFAULT)
@@ -1366,7 +1366,7 @@ bool CSiteManagerDialog::UpdateBookmark(Bookmark &bookmark, const CServer& serve
 	bookmark.m_localDir = xrc_call(*this, "ID_BOOKMARK_LOCALDIR", &wxTextCtrl::GetValue);
 	bookmark.m_remoteDir = CServerPath();
 	bookmark.m_remoteDir.SetType(server.GetType());
-	bookmark.m_remoteDir.SetPath(xrc_call(*this, "ID_BOOKMARK_REMOTEDIR", &wxTextCtrl::GetValue));
+	bookmark.m_remoteDir.SetPath(xrc_call(*this, "ID_BOOKMARK_REMOTEDIR", &wxTextCtrl::GetValue).ToStdWstring());
 	bookmark.m_sync = xrc_call(*this, "ID_BOOKMARK_SYNC", &wxCheckBox::GetValue);
 	bookmark.m_comparison = xrc_call(*this, "ID_BOOKMARK_COMPARISON", &wxCheckBox::GetValue);
 
@@ -1383,33 +1383,32 @@ bool CSiteManagerDialog::UpdateServer(Site &server, const wxString &name)
 	if (!xrc_call(*this, "ID_PORT", &wxTextCtrl::GetValue).ToULong(&port) || !port || port > 65535) {
 		port = CServer::GetDefaultPort(protocol);
 	}
-	wxString host = xrc_call(*this, "ID_HOST", &wxTextCtrl::GetValue);
+	std::wstring host = xrc_call(*this, "ID_HOST", &wxTextCtrl::GetValue).ToStdWstring();
 	// SetHost does not accept URL syntax
 	if (!host.empty() && host[0] == '[') {
-		host.RemoveLast();
-		host = host.Mid(1);
+		host = host.substr(1, host.size() - 2);
 	}
 	server.m_server.SetHost(host, port);
 
 	auto logon_type = GetLogonType();
 	server.m_server.SetLogonType(logon_type);
 
-	server.m_server.SetUser(xrc_call(*this, "ID_USER", &wxTextCtrl::GetValue),
-							xrc_call(*this, "ID_PASS", &wxTextCtrl::GetValue));
-	server.m_server.SetAccount(xrc_call(*this, "ID_ACCOUNT", &wxTextCtrl::GetValue));
+	server.m_server.SetUser(xrc_call(*this, "ID_USER", &wxTextCtrl::GetValue).ToStdWstring(),
+							xrc_call(*this, "ID_PASS", &wxTextCtrl::GetValue).ToStdWstring());
+	server.m_server.SetAccount(xrc_call(*this, "ID_ACCOUNT", &wxTextCtrl::GetValue).ToStdWstring());
 
-	server.m_server.SetKeyFile(xrc_call(*this, "ID_KEYFILE", &wxTextCtrl::GetValue));
+	server.m_server.SetKeyFile(xrc_call(*this, "ID_KEYFILE", &wxTextCtrl::GetValue).ToStdWstring());
 
 	server.m_comments = xrc_call(*this, "ID_COMMENTS", &wxTextCtrl::GetValue);
 	server.m_colour = CSiteManager::GetColourFromIndex(xrc_call(*this, "ID_COLOR", &wxChoice::GetSelection));
 
-	const wxString serverType = xrc_call(*this, "ID_SERVERTYPE", &wxChoice::GetStringSelection);
+	std::wstring const serverType = xrc_call(*this, "ID_SERVERTYPE", &wxChoice::GetStringSelection).ToStdWstring();
 	server.m_server.SetType(CServer::GetServerTypeFromName(serverType));
 
 	server.m_default_bookmark.m_localDir = xrc_call(*this, "ID_LOCALDIR", &wxTextCtrl::GetValue);
 	server.m_default_bookmark.m_remoteDir = CServerPath();
 	server.m_default_bookmark.m_remoteDir.SetType(server.m_server.GetType());
-	server.m_default_bookmark.m_remoteDir.SetPath(xrc_call(*this, "ID_REMOTEDIR", &wxTextCtrl::GetValue));
+	server.m_default_bookmark.m_remoteDir.SetPath(xrc_call(*this, "ID_REMOTEDIR", &wxTextCtrl::GetValue).ToStdWstring());
 	server.m_default_bookmark.m_sync = xrc_call(*this, "ID_SYNC", &wxCheckBox::GetValue);
 	server.m_default_bookmark.m_comparison = xrc_call(*this, "ID_COMPARISON", &wxCheckBox::GetValue);
 
@@ -1434,11 +1433,12 @@ bool CSiteManagerDialog::UpdateServer(Site &server, const wxString &name)
 	if (xrc_call(*this, "ID_CHARSET_UTF8", &wxRadioButton::GetValue))
 		server.m_server.SetEncodingType(ENCODING_UTF8);
 	else if (xrc_call(*this, "ID_CHARSET_CUSTOM", &wxRadioButton::GetValue)) {
-		wxString encoding = xrc_call(*this, "ID_ENCODING", &wxTextCtrl::GetValue);
+		std::wstring encoding = xrc_call(*this, "ID_ENCODING", &wxTextCtrl::GetValue).ToStdWstring();
 		server.m_server.SetEncodingType(ENCODING_CUSTOM, encoding);
 	}
-	else
+	else {
 		server.m_server.SetEncodingType(ENCODING_AUTO);
+	}
 
 	if (xrc_call(*this, "ID_BYPASSPROXY", &wxCheckBox::GetValue))
 		server.m_server.SetBypassProxy(true);
@@ -1519,12 +1519,12 @@ void CSiteManagerDialog::OnKeyFileBrowse(wxCommandEvent&)
 	wxFileDialog dlg(this, _("Choose a key file"), wxString(), wxString(), wildcards, wxFD_OPEN|wxFD_FILE_MUST_EXIST);
 
 	if (dlg.ShowModal() == wxID_OK) {
-		wxString keyFilePath = dlg.GetPath();
+		std::wstring keyFilePath = dlg.GetPath().ToStdWstring();
 		// If the selected file was a PEM file, LoadKeyFile() will automatically convert it to PPK
 		// and tell us the new location.
 		CFZPuttyGenInterface fzpg(this);
 
-		wxString keyFileComment, keyFileData;
+		std::wstring keyFileComment, keyFileData;
 		if (fzpg.LoadKeyFile(keyFilePath, false, keyFileComment, keyFileData)) {
 			XRCCTRL(*this, "ID_KEYFILE", wxTextCtrl)->ChangeValue(keyFilePath);
 		}
@@ -2435,5 +2435,5 @@ ServerProtocol CSiteManagerDialog::GetProtocol() const
 
 LogonType CSiteManagerDialog::GetLogonType() const
 {
-	return CServer::GetLogonTypeFromName(xrc_call(*this, "ID_LOGONTYPE", &wxChoice::GetStringSelection));
+	return CServer::GetLogonTypeFromName(xrc_call(*this, "ID_LOGONTYPE", &wxChoice::GetStringSelection).ToStdWstring());
 }
